@@ -31,7 +31,6 @@ from .calculations import (
     create_matrix,
     solve_network,
     solve_drain_current,
-    solve_nodal_current,
     scale_sol,
 )
 
@@ -50,7 +49,3 @@ from .dynamics import (
 from .units import (
     get_units
 )
-
-from ._models import (
-    set_chen_params,
-)
\ No newline at end of file
