@@ -2,9 +2,10 @@
 # -*- coding: utf-8 -*-
 #
 # Functions to evolve nanowire networks over time.
+# See: https://doi.org/10.1038/nature06932
 # 
 # Author: Marcus Kasdorf
-# Date:   July 28, 2021
+# Date:   July 26, 2021
 
 import numpy as np
 import networkx as nx
@@ -18,8 +19,7 @@ from .calculations import solve_drain_current
 from ._models import (
     resist_func,
     _HP_model_no_decay,
-    _HP_model_decay,
-    _HP_model_chen,
+    _HP_model_decay, 
 )
 
 
@@ -66,7 +66,7 @@ def solve_evolution(
     tol : float, optional
         Tolerance of `scipy.integrate.solve_ivp`. Defaults to 1e-12.
 
-    model : {"default", "decay", "chen"}, optional
+    model : {"default", "decay"}, optional
         Evolutionary model type. Default: "default".
 
     solver : str, optional
@@ -85,57 +85,39 @@ def solve_evolution(
         List of the edges corresponding with each `w`.
 
     """
-    if model not in ("default", "decay", "chen"):
-        raise ValueError(f'Unsupported model type: model="{model}"')
-
     # Default window function
     if window_func is None:
         window_func = lambda x: 1
 
-    # Get list of junction edges and state variable w
+    # Model type
+    _deriv = None
+    if model == "default":
+        _deriv = _HP_model_no_decay
+    elif model == "decay":
+        _deriv = _HP_model_decay
+
+    if _deriv is None:
+        raise ValueError(f'Unsupported model type: model="{model}"')
+
+    # Get list of junction edges and the time bounds
+    t_span = (t_eval[0], t_eval[-1])
     edge_list, w0 = map(list, zip(*[
         ((u, v), w) for u, v, w in NWN.edges.data("w") if w is not None]
     ))
-    
-    # Get list of tau
-    tau0 = [tau for _, _, tau in NWN.edges.data("tau") if tau is not None]
-
-    # Get list of epsilon
-    epsilon0 = [ep for _, _, ep in NWN.edges.data("epsilon") if ep is not None]
-
-    # Define initial state and associated derivative
-    if model == "default":
-        _deriv = _HP_model_no_decay
-        y0 = w0
-    elif model == "decay":
-        _deriv = _HP_model_decay
-        y0 = w0
-    elif model == "chen":
-        _deriv = _HP_model_chen
-        y0 = np.hstack((w0, tau0, epsilon0))
-        if "sigma" not in NWN.graph.keys():
-            raise AttributeError(
-                "sigma, theta, and a must be set before using the Chen model.")
 
     # Solve the system of ODEs
-    t_span = (t_eval[0], t_eval[-1])
     sol = solve_ivp(
-        _deriv, t_span, y0, "DOP853", t_eval, 
+        _deriv, t_span, w0, "DOP853", t_eval, 
         atol = tol, 
         rtol = tol,
         args = (NWN, source_node, drain_node, voltage_func, edge_list, 
             window_func, solver, kwargs)
     )
+    final_w = sol.y[:, -1]
 
-    # Update NWN to final state variables.
-    if model == "default":
-        set_state_variables(NWN, sol.y[:, -1], edge_list)
-    elif model == "decay":
-        set_state_variables(NWN, sol.y[:, -1], edge_list)
-    elif model == "chen":
-        w_list, tau_list, eps_list = np.split(sol.y, 3)
-        set_state_variables(NWN, w_list[:, -1], 
-            tau_list[:, -1], eps_list[:, -1], edge_list)
+    # Update the w value of each edge junction
+    attrs = {edge: {"w": final_w[i]} for i, edge in enumerate(edge_list)}
+    nx.set_edge_attributes(NWN, attrs)
 
     return sol, edge_list
 
@@ -180,20 +162,16 @@ def set_state_variables(NWN: nx.Graph, *args):
     
     """
     # Only scalar w passed
-    if len(args) == 1:
-        if isinstance(args[0], Number):
-            w = args[0]
-            R = resist_func(NWN, w)
+    if len(args) == 1 and isinstance(args[0], Number):
+        w = args[0]
+        R = resist_func(NWN, w)
 
-            attrs = {
-                edge: {
-                    "w": w, "conductance": 1 / R
-                } for edge in NWN.edges if NWN.edges[edge]["type"] == "junction"
-            }
-            nx.set_edge_attributes(NWN, attrs)
-
-        else:
-            raise ValueError("Invalid arguments.")
+        attrs = {
+            edge: {
+                "w": w, "conductance": 1 / R
+            } for edge in NWN.edges if NWN.edges[edge]["type"] == "junction"
+        }
+        nx.set_edge_attributes(NWN, attrs)
 
     elif len(args) == 2:
         # vector w and edge_list passed
@@ -209,7 +187,7 @@ def set_state_variables(NWN: nx.Graph, *args):
             nx.set_edge_attributes(NWN, attrs)
 
         # scalar w and scalar tau passed
-        elif isinstance(args[0], Number) and isinstance(args[1], Number):
+        if isinstance(args[0], Number) and isinstance(args[1], Number):
             w, tau = args
             R = resist_func(NWN, w)
 
@@ -221,9 +199,6 @@ def set_state_variables(NWN: nx.Graph, *args):
             nx.set_edge_attributes(NWN, attrs)
             NWN.graph["tau"] = tau
 
-        else:
-            raise ValueError("Invalid arguments.")
-
     elif len(args) == 3:
         # vector w, vector tau, and edge_list passed
         if (isinstance(args[0], np.ndarray) and 
@@ -256,9 +231,6 @@ def set_state_variables(NWN: nx.Graph, *args):
             NWN.graph["tau"] = tau
             NWN.graph["epsilon"] = epsilon
 
-        else:
-            raise ValueError("Invalid arguments.")
-
     elif len(args) == 4:
         # vector w, vector tau, vector epsilon, and edge_list passed
         if (isinstance(args[0], np.ndarray) and 
@@ -276,9 +248,6 @@ def set_state_variables(NWN: nx.Graph, *args):
             }
             nx.set_edge_attributes(NWN, attrs)
 
-        else:
-            raise ValueError("Invalid arguments.")
-
     else:
         raise ValueError("Invalid number of arguments.")
 
